/*
*******************************************************************************************************************
*												LED ROTATE DEMO
* Description:	This program rotates the LED onboard with a rate defined by the number of key stroke to RESET.
*				The RESET key is assigned a function of general purpose I/O instead of MCLR reset
*				by disabling the MCLR feature in Configuration Bits. The program initialize a delay timer dlyTime
*				to a startup value of 10 in millisec. A second variable dlyCnt is used as the counter for accumulate
*				the number of time interval elapsed in 1 millisec interval. If the rate is 20 millisec, 
*				we need to accumulate dlyCnt to a value of 20 to achieve a total delay time of 20 millisec.
*				Then the LED is updated by a left shift on the LEDCnt variable showing a visual effect.
* File:			..\LEDRotate\LEDRotateMain.c
* Software:		HiTech PICC Lite compiler version 9.60 under MPLAB IDE v7.50 or higher
* Programmer: 	John Leung, TechToys Co. (www.TechToys.com.hk)
* Hardware:		nRF_CB_Eval_1a, at Vdd=5V powered by PICKit2 -OR-
*				Internal regulator of Silabs CP2102 USB<->UART bridge with 5V supplied by USB cable
* Date:			6th May 2007
* Version:		1.0
*
* 												All Rights Reserved
*
*******************************************************************************************************************
*/


#include <htc.h>		//header files for all supported chips includes PIC16F690 (..\include\pic16f685.h)
#include "delay.h"		//delay function offered by PICCLite contained within INSTALL DIR\samples\delay

/*
********************************************************************************************************************
*												Configuration Bit Section
*
* Configuration bit setting for 16F690 : Internal OSC with no clock out, watchdog disabled, etc.
* Please consult \\HI-TECH Software\PICC\lite\9.60\include\pic16f685.h for meaning of the arguments.
********************************************************************************************************************
*/
__CONFIG(INTIO&WDTDIS&PWRTDIS&MCLRDIS&UNPROTECT&BORDIS&IESODIS&FCMDIS);


/*
********************************************************************************************************************
* 														MAIN
* 
********************************************************************************************************************
*/
void main(void)
{
	unsigned char LEDCnt=0b00000001, dlyCnt, dlyTime=20;

	ANSEL  	= 0x00;
	ANSELH 	= 0x00;		//all digital operation
	SCS 	= 1;		//internal oscillator is used for system clock and 
						//accept the deafulat clock speed of 4MHz defined by
						//IRCF<2:0>=110

	TRISC  = 0xF0;		//configure the lower nibble RC<3:0> as outputs
	TRISA3 = 1;			//RA3 pin as an input
	PORTC  = LEDCnt;	//Update PORTC

while(1)
{
	if (RA3==0)							//detect key stroke here
	{
		DelayMs(20);					//debounce the key for 20ms
		if(RA3==0) 						//after debouncing period 20ms, if RA3 is still low, it is a real key press
		{
			dlyTime=dlyTime+20;			//increment the delay counter
			if(dlyTime==120) dlyTime=20;//reset the delay timer if it is more than 100 millisec	
			while(RA3==0);				//wait until key release for a real action
		}
	}

	DelayMs(1);

	if((dlyCnt++)==dlyTime)				//when the delay counter reaches delay time dlyTime defined above...
	{									//we need to update the LED status
	dlyCnt=0;							//reset delay counter
	LEDCnt = LEDCnt<<1;					//left shift counter i.
	if(LEDCnt==0b00010000) 
	LEDCnt=0b00000001;					//reset the LEDCnt	
	PORTC = LEDCnt;						//update LED counter connected to PORTC
	}

}
}
